
* THE IMPACT OF MEDICARE PART D ON PORTFOLIO CHOICE

	
*** Change path to correct folder ***
global portfolio "C:\Portfolio"

************************************************************
clear
capture log close
set more off

cd "$portfolio"
************************************************************

use "$portfolio\data", clear


* Interaction term for DD model
gen age65_post=age65*post

* Group Specific Linear Time Trend
gen age65_year=age65*year


* Interaction terms for event study model
forval k=1/8{
	gen inter`k'=age65*y`k'
}



******************
* REGRESSIONS 
******************
*set table format
loc format "c(b(star fmt(%9.4f)) se(par fmt(%9.4f))) starl(* 0.10 ** 0.05 *** 0.01) stat(N N_g, fmt(0 0)) compress varlabels(_cons Constant)l replace"
loc covar "age agesq married divorced widowed hhres hpi CPSunempl census2-census9 y2-y8"

log using regressions.log, text
* Table 1: Panel A
********************
est clear
xtivreg2 ownrisky age65_post inter5 age65 age65_year `covar', cl(hhid age) fe i(hhidpn)
	est sto tab1
xtivreg2 riskyshare age65_post inter5 age65 age65_year `covar', cl(hhid age) fe i(hhidpn)
	est sto tab2

loc title1 "Table 1, Panel A: Effect of Medicare Part D on Portfolio Choice"
loc mtitle1 ""Owns Risky Assets" "Risky Assets Share""
esttab tab* using "tab1a.rtf", `format' title(`title1') mtitle(`mtitle1')



* Table 1: Panel B
********************
loc health "cesd2 cesdsq cesdmiss srh2-srh5 shltmiss conde2 condesq condemiss"

est clear
xtivreg2 ownrisky age65_post inter5 age65 age65_year `covar' `health', cl(hhid age) fe i(hhidpn)
	est sto tab1
xtivreg2 riskyshare age65_post inter5 age65 age65_year `covar' `health', cl(hhid age) fe i(hhidpn)
	est sto tab2

loc title1 "Table: Evaluating Pathways - Ownership of Risky Assets"
esttab tab* using "tab1b.rtf", `format' title(`title1')


* Table 1: Panel C
********************
est clear	
xtivreg2 ownrisky age65_post inter5 age65 age65_year `covar' livexptn2 livexptnmiss, cl(hhid age) fe i(hhidpn)
	est sto tab1
xtivreg2 riskyshare age65_post inter5 age65 age65_year `covar' livexptn2 livexptnmiss, cl(hhid age) fe i(hhidpn)
	est sto tab2
	

loc title1 "Table: Evaluating Pathways - Ownership of Risky Assets"
esttab tab* using "tab1c.rtf", `format' title(`title1')



* Flexible Specification or Event Study Model(2004 is the reference year)
**************************************************************************
loc covar2 "age agesq married divorced widowed hhres hpi CPSunempl census2-census9"
est clear
xtivreg2 ownrisky inter1-inter4 inter6-inter8 age65 y1-y4 y6-y8 `covar2', cl(hhid age) fe i(hhidpn)
	est sto tab1
xtivreg2 riskyshare inter1-inter4 inter6-inter8 age65 y1-y4 y6-y8 `covar2', cl(hhid age) fe i(hhidpn)
	est sto tab2

loc title1 "Flexible Specification"
loc mtitle1 ""Owns Risky Assets" "Risky Assets Share""
esttab tab* using "flex.rtf", `format' title(`title1') mtitle(`mtitle1')
esttab tab* using "flex.csv", `format' title(`title1') mtitle(`mtitle1')


* Footnote 1
*************
gen unemage65=CPSunempl*age65
gen hpiage65=hpi*age65

est clear
xtivreg2 ownrisky age65_post inter5 age65 age65_year `covar' unemage65 hpiage65, cl(hhid age) fe i(hhidpn)
	est sto tab1
xtivreg2 riskyshare age65_post inter5 age65 age65_year `covar' unemage65 hpiage65, cl(hhid age) fe i(hhidpn)
	est sto tab2

loc title1 "Robustness Check"
loc mtitle1 ""Owns Risky Assets" "Risky Assets Share""
esttab tab* using "ftnote1.rtf", `format' title(`title1') mtitle(`mtitle1')


* Figure 1
***************
* Mean ownership by age group for figure 1
tab age65, sum(ownrisky)

* Pre 2003 ownership rate
sum ownrisky if year<=2003

* sample used in riskyshare regression 
xtivreg2 riskyshare age65_post age65 age65_year `covar', cl(hhid age) fe i(hhidpn)
	keep if riskyshare<.
	gen s=e(sample)
	egen c=count(s), by(hhidpn)
	drop if c==1

* Mean share by age group for figure 1
tab age65, sum(riskyshare)
* Pre 2003 share
sum riskyshare if year<=2003


log close



